@@ -92,15 +92,16 @@ can_exposures(struct WindowRec *windowrec)
 static void
 mag_motion(XEvent * event)
 {
+    MYTRACE((stderr, "mag_motion!\n"));
     new_mag_x = event->xmotion.x + mag_conv_x;
     main_x = event->xmotion.x_root - new_mag_x;
     new_mag_y = event->xmotion.y + mag_conv_y;
     main_y = event->xmotion.y_root - new_mag_y;
 
     if (new_mag_x != mag_x || new_mag_y != mag_y)
-	globals.events.flags |= EV_MAG_MOVE;
+	globals.ev.flags |= EV_MAG_MOVE;
     else
-	globals.events.flags &= ~EV_MAG_MOVE;
+	globals.ev.flags &= ~EV_MAG_MOVE;
 }
 
 void
@@ -114,13 +115,13 @@ mag_release(XEvent * event)
 	else {
 	    XDestroyWindow(DISP, magnifier.win);
 	    if (drawing_mag) {
-		globals.events.flags |= EV_MAG_GONE;
+		globals.ev.flags |= EV_MAG_GONE;
 	    }
 	    magnifier.win = (Window) 0;
 	    mouse_motion = mouse_release = null_mouse;
-	    globals.events.flags &= ~EV_MAG_MOVE;
+	    globals.ev.flags &= ~EV_MAG_MOVE;
 	    globals.cursor.flags &= ~CURSOR_MAG;
-	    globals.events.flags |= EV_CURSOR;
+	    globals.ev.flags |= EV_CURSOR;
 	    can_exposures(&magnifier);
 	    /*
 	      Workaround for bug #703304:
@@ -136,9 +137,9 @@ mag_release(XEvent * event)
 	      may cause a `BadDrawable' X error with color material (e.g. from #702288),
 	      or a `draw_part: shouldn't happen: POST encountered' error. Neither do
 	      the following work:
-	         globals.events.flags |= EV_EXPOSE;		(doesn't fix the bug)
+	         globals.ev.flags |= EV_EXPOSE;		(doesn't fix the bug)
 		 draw_page();			(same effect as redraw(&mane))
-		 globals.events.flags |= EV_NEWPAGE;	(works, but is crude and causes flicker)
+		 globals.ev.flags |= EV_NEWPAGE;	(works, but is crude and causes flicker)
 		 
 	      So I decided to use expose() for the time being, which 
 	      sets mane.min_x to the current x point (which doesn't happen
@@ -389,7 +390,7 @@ do_movemag(int x, int y)
     mag_x = x;
     mag_y = y;
     if (mag_x == new_mag_x && mag_y == new_mag_y)
-	globals.events.flags &= ~EV_MAG_MOVE;
+	globals.ev.flags &= ~EV_MAG_MOVE;
     compute_mag_pos(&xx, &yy);
     XMoveWindow(DISP, magnifier.win, xx, yy);
     scroll_window(&magnifier,
@@ -514,7 +515,7 @@ void
 move_magnifier(void)
 {
     if (magnifier.win == (Window) 0)
-	globals.events.flags &= ~EV_MAG_MOVE;
+	globals.ev.flags &= ~EV_MAG_MOVE;
     else if (abs(new_mag_x - mag_x) > 2 * abs(new_mag_y - mag_y))
 	do_movemag(new_mag_x, mag_y);
     else if (abs(new_mag_y - mag_y) > 2 * abs(new_mag_x - mag_x))
@@ -685,17 +686,20 @@ Act_magnifier(Widget w, XEvent *event,
 #endif
     UNUSED(w);
 
+    MYTRACE((stderr, "magnifier!\n"));
+    
     if (block_this_mouse_event())
 	return;
     else if (dvi_file_changed()) {
-	globals.events.flags |= EV_RELOAD;
+	globals.ev.flags |= EV_RELOAD;
 	return;
     }
 
 #ifdef MOTIF
     /* see xm_menu.c for an explanation of this */
-    if (pulldown_menu_active(event->xany.serial))
+    if (pulldown_menu_active(event->xany.serial)) {
 	return;
+    }
 #endif
     
     if (bg_current == NULL) {
@@ -755,11 +759,11 @@ Act_magnifier(Widget w, XEvent *event,
     }
 #ifndef MOTIF
     XTranslateCoordinates(DISP, event->xbutton.window, mane.win,
-	    0, 0, &mag_conv_x, &mag_conv_y, &throwaway);
+			  0, 0, &mag_conv_x, &mag_conv_y, &throwaway);
 #endif
 
     globals.cursor.flags |= CURSOR_MAG;
-    globals.events.flags |= EV_CURSOR;
+    globals.ev.flags |= EV_CURSOR;
     
     mag_x = event->xbutton.x + mag_conv_x;
     mag_y = event->xbutton.y + mag_conv_y;
