@@ -189,7 +189,7 @@ static	struct xtimer	gs_timer	= {NULL, {0, 0}, gs_timer_proc};
 #else
 static void gs_alarm(struct xtimer *timer);
 static struct xtimer gs_timer = {NULL, {0, 0}, XTM_DEFAULT, gs_alarm
-#if TIMER_HACK
+#if XDVI_XT_TIMER_HACK
 				    , NULL, NULL
 #endif
 };
@@ -255,7 +255,7 @@ read_from_gs(int fd)
 
 	    showto(p);
 	    p += 3;
-	    (void) bcopy(p, line, line_end - p);
+	    memmove(line, p, line_end - p);
 	    line_end -= p - line;
 	    linepos = p = line;
 	    --p;
@@ -265,7 +265,7 @@ read_from_gs(int fd)
 	if (p != NULL) {
 	    ++p;
 	    showto(p);
-	    (void) bcopy(p, line, line_end - p);
+	    memmove(line, p, line_end - p);
 	    line_end -= p - line;
 	}
 	linepos = line_end;
@@ -362,7 +362,7 @@ gs_send(const char *cp, size_t len)
 	if (bytes > 0) {
 	    if (bytes >= (unsigned)(cp_end - cp))
 		bytes = cp_end - cp;
-	    bcopy(cp, GS_outb_in, bytes);
+	    memcpy(GS_outb_in, cp, bytes);
 	    cp += bytes;
 	    GS_outb_in += bytes;
 	    if (GS_outb_in == GS_outb_limit)
