@@ -180,6 +180,7 @@ typedef	char		Bool3;		/* Yes/No/Maybe */
 extern unsigned long time_start, time_end;
 #endif
 
+#include <X11/Xmd.h>	/* get WORD64 and LONG64 */
 
 #ifndef WORD64
 # ifdef LONG64
@@ -194,8 +195,9 @@ typedef unsigned long xuint32;
 #define UNUSED(x) ((void)(x))
 #endif
 
-#ifdef	VMS
 #include <string.h>
+
+#ifdef	VMS
 #define	index	strchr
 #define	rindex	strrchr
 #define	bzero(a, b)	(void) memset ((void *) (a), 0, (size_t) (b))
@@ -710,6 +712,10 @@ extern struct program_globals {
     char *orig_locale;		/* original locale we are running in */
     unsigned long debug;	/* debugging option */
 
+    /* for older Motif versions or LessTif, which have broken
+       handling of Act_motion() / Act_release() events */
+    Boolean broken_motif_event_handling;
+    
     /* offset from c-style (0 based) numbers to real pagenumbers;
        also contains the offset that user has set via Act_declare_page_number() */
     int pageno_correct;
@@ -991,12 +997,16 @@ extern Widget statusline;
  * also uses XtAppAddTimeOut() for Xaw, we always need to define it.
  * See the comment in events.c for further explanations.
  */
-#define TIMER_HACK 1
+#if LD_ALLOWS_MULTIPLE_DEFINITIONS
+# define XDVI_XT_TIMER_HACK 1
+#else
+# define XDVI_XT_TIMER_HACK 0
+#endif
 
 /* globally used GUI stuff */
 #ifdef MOTIF
 #include <Xm/Xm.h>
-/* Note: non-k xdvi has MOTIF_TIMERS here, we use TIMER_HACK instead (see above) */
+/* Note: non-k xdvi has MOTIF_TIMERS here, we use XDVI_XT_TIMER_HACK instead (see above) */
 
 # ifndef DDIST
 #  define DDIST 4
@@ -1106,6 +1116,8 @@ extern void motif_translations_hack(void);
 #define iconv libiconv
 #endif /* 0 */
 
+typedef ICONV_CHAR_PPTR_TYPE iconv_char_pptrT;
+
 #define DEVEL_MODE 0
 
 #endif	/* XDVI_H_ */
